function [x, v , xdot , vdot , s , dm , h11 , h12 ] = Generate_Dyn_Fully_Anticipated( shock , par )

% Parameter
a2 = par.a2;
b3 = par.b3;
l1 = par.l1;
l2 = par.l2;
del = par.del;
lam = par.lam;
f1 = par.f1;
steps = par.steps;
SimEnd = par.SimEnd;

% Shock parameter
t0 = shock.t0;
T  = shock.T;
t1 = shock.t1;
bet0 = shock.bet0;
bet1 = shock.bet1;
s0 = shock.s0;
mdot  = shock.mdot;
mdot2 = shock.mdot2;

% Timing
tt0 = 0:1/steps:t0;
tt1 = t0+1/steps:1/steps:T;
tt2 = T+1/steps:1/steps:t1;
tt3 = t1+1/steps: 1/steps: SimEnd;

% Shock processes
ss0 = s0 * ones(1,length(tt0));
ss1 = s0 + bet0*( tt1 - t0 );
ss2 = ss1(end) - bet1*( tt2 - T );
ss3 = ss2(end) * ones(1,length(tt3));
sbar = ss1(end);
s1 = ss2(end);
s = [ss0 ss1 ss2 ss3 ];

dm0 = 0 * ones(1,length(tt0));
dm1 = 0 * ones(1,length(tt1));
dm2 = mdot  * ones(1,length(tt2));
dm3 = mdot2 * ones(1,length(tt3));
dm = [dm0 dm1 dm2 dm3];

% System matrices
A=[a2 lam/del; l2 l2-l1/del];
B=[b3 0; 0 1];
 
dstar = l2 + l1*f1*a2/(b3+lam*f1);
D = [a2/(b3+lam*f1) 0; dstar l2];


% EVs
[H , R] = eig(A^-1*B);
[i_unstable, j_unstable] = find(R>0);
[i_stable, j_stable] = find(R<0);
r1 = R(i_unstable , j_unstable); 
r2 = R(i_stable , j_stable); 
h11 = H(1,i_unstable)/H(2,i_unstable);
h12 = H(1,i_stable)/H(2,i_stable);
 
Htilde = [h11 h12; 1 1];

F = Htilde^-1*A^-1*B*D;
f11=F(1,1); f12=F(1,2);
f21=F(2,1); f22=F(2,2);

f1star = f11*sbar + f11*bet1*T + f12*mdot; 
f2star = f21*sbar + f21*bet1*T + f22*mdot; 


% Constants
K14 = - (f11 * s1 + f12 *  mdot2)/ r1 * exp(-r1*t1);
K13 = K14 - (f1star/r1 - f11*bet1/r1^2) * ( exp(-r1*T) - exp(-r1*t1) ) + f11*bet1/r1 * ( T*exp(-r1*T) - t1*exp(-r1*t1) ); 
K12 = K13 - f11/r1 * (s0-bet0*t0+bet0/r1) * ( exp(-r1*t0) - exp(-r1*T) ) - f11*bet0/r1 * ( t0*exp(-r1*t0) - T * exp(-r1*T) ); 
K11 = K12 - f11*s0/r1 * ( 1 - exp(-r1*t0) );

K21 = - K11;
K22 = K21 + f21*s0/r2 * ( 1 - exp(-r2*t0) );
K23 = K22 + f21/r2 * (s0-bet0*t0+bet0/r2) * ( exp(-r2*t0) - exp(-r2*T) ) + f21*bet0/r2 * ( t0*exp(-r2*t0) - T * exp(-r2*T) );
K24 = K23 + (f2star/r2 - f21*bet1/r2^2) * ( exp(-r2*T) - exp(-r2*t1) ) - f21*bet1/r2 * ( T*exp(-r2*T) - t1*exp(-r2*t1) ); 


% Solution path of auxiliary variables x and v
xx0 = exp(r1.*tt0) .* K11 - f11*s0/r1 * (1-exp(r1.*tt0));
xx1 = exp(r1.*tt1) .* K12 + f11/r1 * (s0-bet0*t0+bet0/r1) * ( exp(r1.*(tt1-t0)) - 1 ) + f11*bet0/r1 * (t0 * exp(r1*(tt1-t0))-tt1);
xx2 = exp(r1.*tt2) .* K13 + (f1star/r1 - f11*bet1/r1^2) * (exp(r1.*(tt2-T))-1) -  f11*bet1/r1 * (T * exp(r1*(tt2-T))-tt2);
xx3 = exp(r1.*tt3) .* K14 + (f11 * s1 + f12 *  mdot2)/r1 * (exp(r1.*(tt3-t1))-1);

vv0 = exp(r2.*tt0) .* K21 - f21*s0/r2 * (1-exp(r2.*tt0));
vv1 = exp(r2.*tt1) .* K22 + f21/r2 * (s0-bet0*t0+bet0/r2) * ( exp(r2.*(tt1-t0)) - 1 ) + f21*bet0/r2 * (t0 * exp(r2*(tt1-t0))-tt1);
vv2 = exp(r2.*tt2) .* K23 + (f2star/r2 - f21*bet1/r2^2) * (exp(r2.*(tt2-T))-1) -  f21*bet1/r2 * (T * exp(r2*(tt2-T))-tt2);
vv3 = exp(r2.*tt3) .* K24 + (f21 * s1 + f22 *  mdot2)/r2 * (exp(r2.*(tt3-t1))-1);

x = [xx0 xx1 xx2 xx3];
v = [vv0 vv1 vv2 vv3];


% Derivative of x and v
xx0dot = exp(r1.*tt0) .* K11 * r1 + f11*s0/r1 * exp(r1.*tt0) * r1;
xx1dot = exp(r1.*tt1) .* K12 * r1 + f11/r1 * (s0-bet0*t0+bet0/r1) * exp(r1.*(tt1-t0)) * r1  + f11*bet0/r1 * (t0 * exp(r1*(tt1-t0)) * r1 - 1 );
xx2dot = exp(r1.*tt2) .* K13 * r1 + (f1star/r1 - f11*bet1/r1^2) * exp(r1.*(tt2-T)) * r1 -  f11*bet1/r1 * (T * exp(r1*(tt2-T)) * r1 - 1);
xx3dot = exp(r1.*tt3) .* K14 * r1 + (f11 * s1 + f12 *  mdot2)/r1 * exp(r1.*(tt3-t1)) * r1;

vv0dot = exp(r2.*tt0) .* K21 * r2 + f21*s0/r2 * (1-exp(r2.*tt0)) * r2;
vv1dot = exp(r2.*tt1) .* K22 * r2 + f21/r2 * (s0-bet0*t0+bet0/r2) *  exp(r2.*(tt1-t0)) * r2 + f21*bet0/r2 * (t0 * exp(r2*(tt1-t0)) * r2 - 1 );
vv2dot = exp(r2.*tt2) .* K23 * r2 + (f2star/r2 - f21*bet1/r2^2) * exp(r2.*(tt2-T)) * r2 -  f21*bet1/r2 * (T * exp(r2*(tt2-T)) * r2 - 1 );
vv3dot = exp(r2.*tt3) .* K24 * r2 + (f21 * s1 + f22 *  mdot2)/r2 * exp(r2.*(tt3-t1)) * r2;

xdot = [xx0dot xx1dot xx2dot xx3dot];
vdot = [vv0dot vv1dot vv2dot vv3dot];
