function output = Generate_Dynamics( par , shock_ant , shock_true , tstar )


%% Solution path until tstar
[x, v , xdot , vdot , s , dm , h11 , h12 ] = Generate_Dyn_Fully_Anticipated( shock_ant , par );

x1 = x(1:floor(tstar*par.steps+1));
v1 = v(1:floor(tstar*par.steps+1));
xdot1 = xdot(1:floor(tstar*par.steps+1));
vdot1 = vdot(1:floor(tstar*par.steps+1));

s_ant = s;
dm_ant = dm;

c_t_ant1 = shock_ant.mdot * ones(1,floor(tstar(1)*par.steps+1));
T_t_ant1 = shock_ant.T * ones(1,floor(tstar(1)*par.steps+1));
t1_t_ant1 = shock_ant.t1 * ones(1,floor(tstar(1)*par.steps+1));


%% Solution path after tstar

x_in_tstar = x1(end);
v_in_tstar = v1(end);

if tstar < shock_true.T % If tstar  < T:

    [x, v , xdot , vdot , s , dm , h11, h12] = Generate_Dyn_After_tstar( shock_true , par , tstar , x_in_tstar, v_in_tstar );

else % If tstar  > T:
    
    [x, v , xdot , vdot , s , dm , h11, h12] = Generate_Dyn_After_tstar_large( shock_true , par , tstar , x_in_tstar, v_in_tstar );

end



% Save
x2 = x;
v2 = v;
xdot2 = xdot;
vdot2 = vdot;

s_true = s;
dm_true = dm;

c_t_ant1  = [c_t_ant1 shock_true.mdot*ones(1,length(x))];
T_t_ant1  = [T_t_ant1 shock_true.T*ones(1,length(x))];
t1_t_ant1 = [t1_t_ant1 shock_true.t1*ones(1,length(x))];



%% Full solution path

x = [x1 x2];
v = [v1 v2];
xdot = [xdot1 xdot2];
vdot = [vdot1 vdot2];

tau = h11*x + h12*v;
mr = x + v;
taudot = h11*xdot + h12*vdot;
mrdot = xdot + vdot;


% Output
gams = - par.a2  * par.f1 /(par.b3 + par.lam*par.f1);
ybar = gams * s_true;
y = ybar - mrdot/par.del;


% Real interest rate
r = -taudot + s_true;

% Inflation
pi = dm_true - mrdot;

% Nominal interest rate
i = r + pi;

% price level
leng_m = length(dm_true);
p = tril(ones(leng_m))*pi'/par.steps;
p = [0; p(1:end-1)];

% Nom. money stock
m = mr + p';

% exchange rate
e = -tau + p';


%% Output
output.y = y;
output.mr = mr;
output.tau = tau;
output.i = i;
output.r = r;
output.pi = pi;
output.p = p;
output.m = m;
output.e = e;
output.s_ant=s_ant;
output.s_true=s_true;
output.dm_ant=dm_ant;
output.dm_true=dm_true;
output.x = x;
output.v = v;
output.E_t_c=c_t_ant1;
output.E_t_T=T_t_ant1;
output.E_t_t1=t1_t_ant1;