function output = Generate_Dynamics_Multiple_tstars( par , shock_ant, shock_true , tstar_vector )


numb_tstars = length(tstar_vector);

shock_ant.T = shock_ant.T_vector(1);
shock_ant.t1 = shock_ant.t1_vector(1);

%% Solution path until tstar
[x, v , xdot , vdot , s , dm , h11 , h12 ] = Generate_Dyn_Fully_Anticipated( shock_ant , par );

x1 = x(1:tstar_vector(1)*par.steps+1);
v1 = v(1:tstar_vector(1)*par.steps+1);
xdot1 = xdot(1:tstar_vector(1)*par.steps+1);
vdot1 = vdot(1:tstar_vector(1)*par.steps+1);

s_ant = s;
dm_ant = dm;

T_t_ant1 = shock_ant.T * ones(1,tstar_vector(1)*par.steps+1);
c_t_ant1 = shock_ant.mdot * ones(1,tstar_vector(1)*par.steps+1);
t1_t_ant1 = shock_ant.t1 * ones(1,tstar_vector(1)*par.steps+1);

%% Solution path after tstar

for jj = 2:numb_tstars
    
    x_in_tstar = x1(end);
    v_in_tstar = v1(end);
    
    shock_ant.T = shock_ant.T_vector(jj);
    shock_ant.t1 = shock_ant.t1_vector(jj);
    tstar = tstar_vector(jj-1);

    if tstar < shock_true.T % If tstar  < T:
        
        [x, v , xdot , vdot , s , dm , h11, h12] = Generate_Dyn_After_tstar( shock_ant , par , tstar , x_in_tstar, v_in_tstar );
        
    else % If tstar  > T:
        
        [x, v , xdot , vdot , s , dm , h11, h12] = Generate_Dyn_After_tstar_large( shock_ant , par , tstar , x_in_tstar, v_in_tstar );
        
    end
    
    % Save
    Tbreakdiff = round((tstar_vector(jj)-tstar_vector(jj-1))*par.steps);
    
    x1 = [x1 x(1:Tbreakdiff)];
    v1 = [v1 v(1:Tbreakdiff)];
    xdot1 = [xdot1 xdot(1:Tbreakdiff)];
    vdot1 = [vdot1 vdot(1:Tbreakdiff)];
    T_t_ant1 = [T_t_ant1 shock_ant.T*ones(1,Tbreakdiff)];
    c_t_ant1 = [c_t_ant1 shock_ant.mdot*ones(1,Tbreakdiff)];
    t1_t_ant1 =[t1_t_ant1 shock_ant.t1*ones(1,Tbreakdiff)];

end

%% Solution path after last tstar

x_in_tstar = x1(end);
v_in_tstar = v1(end);

if tstar_vector(end) < shock_true.T % If tstar  < T:

    [x, v , xdot , vdot , s , dm , h11, h12] = Generate_Dyn_After_tstar( shock_true , par , tstar_vector(end) , x_in_tstar, v_in_tstar );

else % If tstar  > T:
    
    [x, v , xdot ,  vdot , s , dm , h11, h12] = Generate_Dyn_After_tstar( shock_true , par , tstar_vector(end) , x_in_tstar, v_in_tstar );

end

s_true = s;
dm_true = dm;
T_t_ant1 = [T_t_ant1 shock_true.T*ones(1,length(x))];
c_t_ant1 = [c_t_ant1 shock_true.mdot*ones(1,length(x))];
t1_t_ant1 =[t1_t_ant1 shock_true.t1*ones(1,length(x))];


%% Full solution path

x = [x1 x];
v = [v1 v];
xdot = [xdot1 xdot];
vdot = [vdot1 vdot];


tau = h11*x + h12*v;
mr = x + v;
taudot = h11*xdot + h12*vdot;
mrdot = xdot + vdot;


% Output
gams = - par.a2  * par.f1 /(par.b3 + par.lam*par.f1);
ybar = gams * s_true;
y = ybar - mrdot/par.del;

% Real interest rate
r = -taudot + s_true;

% Inflation
pi = dm_true - mrdot;

% Nominal interest rate
i = r + pi;

% price level
leng_m = length(dm_true);
p = tril(ones(leng_m))*pi'/par.steps;
p = [0; p(1:end-1)];

% Nom. money stock
m = mr + p';

% exchange rate
e = -tau + p';


%% Output
output.y = y;
output.mr = mr;
output.tau = tau;
output.i = i;
output.r = r;
output.pi = pi;
output.p = p;
output.m = m;
output.e = e;
output.s_ant=s_ant;
output.s_true=s_true;
output.dm_ant=dm_ant;
output.dm_true=dm_true;
output.x = x;
output.v = v;
output.E_t_T=T_t_ant1;
output.E_t_c=c_t_ant1;
output.E_t_t1=t1_t_ant1;