function main_OMP_all_scenarios

%% OMP: Deception strategy

[RV_PA_MAG, mdot_values] =  main_RV_PA_MAG;
[RV_PA_START, T_ant_values] =  main_RV_PA_START;
[RV_PA_EXIT, t1_ant_values] =  main_RV_PA_EXIT;


colkk = ['k- '; 'k--'; 'k-.'; 'k: '; 'k  '];


figure

subplot(1,3,1);
plot(mdot_values, RV_PA_MAG.overall.y,colkk(3,:),mdot_values,RV_PA_MAG.overall.pi,colkk(2,:), mdot_values, RV_PA_MAG.overall.loss,colkk(1,:));
hold on; plot([mdot_values(1) mdot_values(end)],[1 1],'k');
xlim([mdot_values(1) mdot_values(end)]);
title('PA-MAG');xlabel('E(c)');

subplot(1,3,2);
plot(T_ant_values,RV_PA_START.overall.y,colkk(3,:),T_ant_values,RV_PA_START.overall.pi,colkk(2,:),T_ant_values,RV_PA_START.overall.loss,colkk(1,:));
hold on; plot([T_ant_values(1) T_ant_values(end)],[1 1],'k');
xlim([T_ant_values(1) T_ant_values(end)]);
title('PA-START');xlabel('E(T)');

subplot(1,3,3);
plot(t1_ant_values,RV_PA_EXIT.overall.y,colkk(3,:),t1_ant_values,RV_PA_EXIT.overall.pi,colkk(2,:),t1_ant_values,RV_PA_EXIT.overall.loss,colkk(1,:));
hold on;plot([t1_ant_values(1) t1_ant_values(end)],[1 1],'k');
xlim([t1_ant_values(1) t1_ant_values(end)]);
title('PA-EXIT');xlabel('E(t_1)');
legend('Vol. Output','Vol. Inflation','Loss')

set(gcf,'PaperUnits','normalized');
set(gcf,'PaperPosition', [0 0 1 0.25]);

print('-dpsc2','fig_sect5_OMP_deception.eps');


%% OMP: Wilthholding Strategy

[RV_PA_MAG, mdot_values , tstar_values_PA_MAG] =  main_RV_withhold_strategy_PA_MAG;
[RV_PA_START, T_ant_values , tstar_values_PA_START] =  main_RV_withhold_strategy_PA_START;
[RV_PA_EXIT, mdot_values , tstar_values_PA_EXIT] =  main_RV_withhold_strategy_PA_EXIT;


colkk = ['k- '; 'k--'; 'k-.'; 'k: '; 'k  '];


figure
subplot(2,3,1);
tstar_values = tstar_values_PA_MAG(1:length(RV_PA_MAG.underest_size.y));
plot(tstar_values,RV_PA_MAG.underest_size.y,colkk(3,:),tstar_values,RV_PA_MAG.underest_size.pi,colkk(2,:),tstar_values,RV_PA_MAG.underest_size.loss,colkk(1,:));
hold on; plot([tstar_values_PA_MAG(1) tstar_values_PA_MAG(end)], [1 1],'k');
title('PA-MAG: E(c)<c');xlabel('t^*_{CB}');

subplot(2,3,2);
tstar_values = tstar_values_PA_START(1:length(RV_PA_START.underest_size.y));
plot(tstar_values,RV_PA_START.underest_size.y,colkk(3,:),tstar_values,RV_PA_START.underest_size.pi,colkk(2,:),tstar_values,RV_PA_START.underest_size.loss,colkk(1,:));
hold on; plot([tstar_values_PA_START(1) tstar_values_PA_START(end)], [1 1],'k');
title('PA-START: E(T)>T');xlabel('t^*_{CB}');

subplot(2,3,3);
tstar_values = tstar_values_PA_EXIT(1:length(RV_PA_EXIT.underest_size.y));
plot(tstar_values,RV_PA_EXIT.underest_size.y,colkk(3,:),tstar_values,RV_PA_EXIT.underest_size.pi,colkk(2,:),tstar_values,RV_PA_EXIT.underest_size.loss,colkk(1,:));
hold on; plot([tstar_values(1) tstar_values(end)], [1 1],'k');
title('PA-EXIT: E(t_1)<t_1'); xlabel('t^*_{CB}');ylim([0.97 1.01])

subplot(2,3,4);
tstar_values = tstar_values_PA_MAG(1:length(RV_PA_MAG.overest_size.y));
plot(tstar_values,RV_PA_MAG.overest_size.y,colkk(3,:),tstar_values,RV_PA_MAG.overest_size.pi,colkk(2,:),tstar_values,RV_PA_MAG.overest_size.loss,colkk(1,:));
hold on; plot([tstar_values_PA_MAG(1) tstar_values_PA_MAG(end)], [1 1],'k');
title('PA-MAG: E(c)>c');xlabel('t^*_{CB}');

subplot(2,3,5);
tstar_values = tstar_values_PA_START(1:length(RV_PA_START.overest_size.y));
plot(tstar_values,RV_PA_START.overest_size.y,colkk(3,:),tstar_values,RV_PA_START.overest_size.pi,colkk(2,:),tstar_values,RV_PA_START.overest_size.loss,colkk(1,:));
hold on; plot([tstar_values(1) tstar_values(end)], [1 1],'k');
title('PA-START: E(T)<T');xlabel('t^*_{CB}');


subplot(2,3,6);
tstar_values = tstar_values_PA_EXIT(1:length(RV_PA_EXIT.overest_size.y));
plot(tstar_values,RV_PA_EXIT.overest_size.y,colkk(3,:),tstar_values,RV_PA_EXIT.overest_size.pi,colkk(2,:),tstar_values,RV_PA_EXIT.overest_size.loss,colkk(1,:));
hold on; plot([tstar_values(1) tstar_values(end)], [1 1],'k');
title('PA-EXIT: E(t_1)>t_1');xlabel('t^*_{CB}'); ylim([0.99 1.08])

legend('Vol. Output','Vol. Inflation','Loss','Location','Northwest')

set(gcf,'PaperUnits','normalized');
set(gcf,'PaperPosition', [0 0 1 0.5]);
print('-dpsc2','fig_sect5_OMP_withholding.eps');






