function  [RV, mdot_values] =  main_RV_PA_MAG

%% Parameter
par.a1 = 0.7;
par.a2 = 0.3;
par.b1 = 0.2;
par.b3 = 0.1;
par.l1 = 1;
par.l2 = 4;
par.del = 0.2;
par.lam = 1-par.a1+par.b1;
par.f1 = 0.5;
par.steps = 100;
par.SimEnd = 40;

alp_y = 0.5;

shock_true.t0 = 0.01;
shock_true.T = 2;
shock_true.t1 = 5;
shock_true.bet0 = 0;
shock_true.bet1 = 0;
shock_true.s0 = 0;
shock_true.mdot = 3;
shock_true.mdot2 = 0;


%% Generate Dynamics
mdot_values =  -1:.25:6;

for ind =  1:length(mdot_values);
    
    shock_ant.t0 = shock_true.t0;
    shock_ant.T =  shock_true.T;
    shock_ant.t1 = shock_true.t1; 
    shock_ant.bet0 = shock_true.bet0;
    shock_ant.bet1 = shock_true.bet1;
    shock_ant.s0 = shock_true.s0;
    shock_ant.mdot = mdot_values(ind);
    shock_ant.mdot2 = shock_true.mdot2;
    
    tstar = shock_true.T;
    
    output_a =  Generate_Dynamics( par , shock_ant , shock_true , tstar );    
    
    % Save values
    y_t_mdot(:,ind) = output_a.y';
    pi_t_mdot(:,ind) = output_a.pi';   
    
    loss_fct(ind) = sum(output_a.pi'.^2./par.steps + alp_y *  output_a.y'.^2/par.steps,1);
    
    if shock_ant.mdot == shock_true.mdot;
        
        yy_baseline = output_a.y';
        ppi_baseline = output_a.pi';
        loss_baseline = loss_fct(ind);
        
    end       
    
end

%% Relative volatilites
RV.overall.y  = RV_overall(y_t_mdot,yy_baseline);
RV.overall.pi = RV_overall(pi_t_mdot,ppi_baseline);
RV.overall.loss = loss_fct / loss_baseline;


RV.AP.y  = RV_during_AP(y_t_mdot,yy_baseline);
RV.AP.pi = RV_during_AP(pi_t_mdot,ppi_baseline);

RV.IP.y  = RV_during_IP(y_t_mdot,yy_baseline);
RV.IP.pi = RV_during_IP(pi_t_mdot,ppi_baseline);

RV.RP.y = RV_during_RP(y_t_mdot,yy_baseline);
RV.RP.pi = RV_during_RP(pi_t_mdot,ppi_baseline);




%% External functions
    function output = std_mean0(input)
        output = (sum(input.^2./par.steps));
    end


    function output = RV_overall(input, baselineval)
        
        STD = std_mean0(input);
        
        STD_base = std_mean0(baselineval);
        
        output = STD/STD_base;
    end

    function output = RV_during_AP(input, baselineval)
        
        input = input(1:shock_true.T*par.steps+1,:);
        baselineval = baselineval(1:shock_true.T*par.steps+1);
        STD = std_mean0(input);
        STD_base = std_mean0(baselineval);
        
        output = STD/STD_base;

    end

    function output = RV_during_IP(input, baselineval)
        
        input = input(shock_true.T*par.steps+2:shock_true.t1*par.steps+1,:);
        baselineval = baselineval(shock_true.T*par.steps+2:shock_true.t1*par.steps+1);
        STD = std_mean0(input);
        STD_base = std_mean0(baselineval);
        
        output = STD/STD_base;

    end

    function output = RV_during_RP(input, baselineval)
        
        input = input(shock_true.t1*par.steps+2:end,:);
        baselineval = baselineval(shock_true.t1*par.steps+2:end);
        STD = std_mean0(input);
        STD_base = std_mean0(baselineval);
        
        output = STD/STD_base;
    end


end