function main_responses_unstable_MM

%% Parameter
par.a1 = 0.7;
par.a2 = 0.3;
par.b1 = 0.2;
par.b3 = 0.1;
par.l1 = 1;
par.l2 = 4;
par.del = 0.2;
par.lam = 1-par.a1+par.b1;
par.f1 = 0.5;
par.steps = 100;
par.SimEnd = 40;


%% FA scenario
shock_true.t0 = 0.5;
shock_true.T = 2;
shock_true.t1 = 5;
shock_true.bet0 = 0;
shock_true.bet1 = 0;
shock_true.s0 = 0;
shock_true.mdot = 3;
shock_true.mdot2 = 0;

shock_ant.t0 = shock_true.t0;
shock_ant.T = shock_true.T;
shock_ant.t1 = shock_true.t1;
shock_ant.bet0 = shock_true.bet0;
shock_ant.bet1 = shock_true.bet1;
shock_ant.s0 = shock_true.s0;
shock_ant.mdot = shock_true.mdot;
shock_ant.mdot2 = shock_true.mdot2;

tstar = shock_true.T;

output_a =  Generate_Dynamics( par , shock_ant , shock_true , tstar );

%% Unstable MM, single adjustment

shock_true.t0 = 0.5;
shock_true.T = 2;
shock_true.t1 = 5;
shock_true.bet0 = 0;
shock_true.bet1 = 0;
shock_true.s0 = 0;
shock_true.mdot = 0;
shock_true.mdot2 = 0;

shock_ant.t0 = shock_true.t0;
shock_ant.T = shock_true.T;
shock_ant.t1 = shock_true.t1;
shock_ant.bet0 = shock_true.bet0;
shock_ant.bet1 = shock_true.bet1;
shock_ant.s0 = shock_true.s0;
shock_ant.mdot = 3;
shock_ant.mdot2 = shock_true.mdot2;

tstar = shock_true.T;

output_b =  Generate_Dynamics( par , shock_ant , shock_true , tstar );


%% Unstable MM, multiple adjustment

shock_true.t0 = 0.5;
shock_true.T = 9;
shock_true.t1 = 12;
shock_true.bet0 = 0;
shock_true.bet1 = 0;
shock_true.s0 = 0;
shock_true.mdot = 0;
shock_true.mdot2 = 0;

shock_ant.t0 = shock_true.t0;
shock_ant.T_vector = 2:2:8;
shock_ant.t1_vector = shock_ant.T_vector + 3;
shock_ant.bet0 = shock_true.bet0;
shock_ant.bet1 = shock_true.bet1;
shock_ant.s0 = shock_true.s0;
shock_ant.mdot = 3;
shock_ant.mdot2 = shock_true.mdot2;

tstar_vector = shock_ant.T_vector;

output_c =  Generate_Dynamics_Multiple_tstars( par , shock_ant , shock_true , tstar_vector );


%% Plots

tend = 10;

colkk = ['k- '; 'k--'; 'k-.'; 'k: '; 'k  '];

tt = 0:1/par.steps:(length(output_a.y)-1)/par.steps;

figure;
subplot(3,2,1);
plot([0 output_a.mr], [0 output_a.tau],colkk(1,:), [0 output_b.mr], [0 output_b.tau],colkk(2,:), [0 output_c.mr], [0 output_c.tau],colkk(3,:));
hold on; plot(0,0,'k.','Markers',15);
axis('tight');yy = xlim;xlim([yy(1)-0.05 0.05])
title('Phase plane');xlabel('Real money stock');ylabel('Terms of trade')

subplot(3,2,2);
plot(tt, output_a.E_t_c,colkk(1,:),tt, output_b.E_t_c,colkk(2,:),tt, output_c.E_t_c,colkk(3,:));
xlim([0 tend]);ylim([-0.1 3.5])
title('Expected magnitude over time (E_t(c))');xlabel('Time')

subplot(3,2,3);
plot(tt, output_a.E_t_T,colkk(1,:),tt, output_b.E_t_T,colkk(2,:),tt(1:tstar_vector(end)*par.steps+1), output_c.E_t_T(1:tstar_vector(end)*par.steps+1),colkk(3,:));
xlim([0 tend]);ylim([0 12])
title('Expected start over time (E_t(T))');xlabel('Time')

subplot(3,2,4);
plot(tt, output_a.E_t_t1,colkk(1,:), tt, output_b.E_t_t1,colkk(2,:), tt(1:tstar_vector(end)*par.steps+1), output_c.E_t_t1(1:tstar_vector(end)*par.steps+1),colkk(3,:));
axis('tight');xlim([0 tend]);ylim([-0.5 12])
title('Expected end over time (E_t(t_1))');xlabel('Time')

subplot(3,2,5);plot(tt, output_a.y,colkk(1,:), tt, output_b.y,colkk(2,:), tt, output_c.y,colkk(3,:));
axis('tight');xlim([0 tend]);
title('Output');xlabel('Time')

subplot(3,2,6);plot(tt, output_a.pi,colkk(1,:), tt, output_b.pi,colkk(2,:), tt, output_c.pi,colkk(3,:));axis('tight');xlim([0 tend]);
title('Inflation rate');xlabel('Time')
legend('Stable MM','Unstable MM (single adj.)','Unstable MM (multiple adj.)','location','northeast');

set(gcf,'PaperUnits','normalized');
set(gcf,'PaperPosition', [0 0 1 0.75]);
print('-dpsc2','fig_sect6_unstable_MM.eps')



end